package com.ruoyi.interfaces.mapper;

import java.util.List;

import com.ruoyi.common.annotation.DataSource;
import com.ruoyi.common.enums.DataSourceType;
import com.ruoyi.interfaces.domain.MdApp;
import org.apache.ibatis.annotations.Mapper;

/**
 * 模型应用Mapper接口
 * 
 * @author 朱得糠
 * @date 2025-08-19
 */
@Mapper
@DataSource(DataSourceType.SLAVE)
public interface MdAppMapper 
{
    /**
     * 查询模型应用
     * 
     * @param appId 模型应用主键
     * @return 模型应用
     */
    public MdApp selectMdAppByAppId(Long appId);

    /**
     * 查询模型应用列表
     * 
     * @param mdApp 模型应用
     * @return 模型应用集合
     */
    public List<MdApp> selectMdAppList(MdApp mdApp);

    /**
     * 新增模型应用
     * 
     * @param mdApp 模型应用
     * @return 结果
     */
    public int insertMdApp(MdApp mdApp);

    /**
     * 修改模型应用
     * 
     * @param mdApp 模型应用
     * @return 结果
     */
    public int updateMdApp(MdApp mdApp);

    /**
     * 删除模型应用
     * 
     * @param appId 模型应用主键
     * @return 结果
     */
    public int deleteMdAppByAppId(Long appId);

    /**
     * 批量删除模型应用
     * 
     * @param appIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMdAppByAppIds(Long[] appIds);
}
